@@ -10,9 +10,8 @@
 
 module Network.OAuth.OAuth2.Internal where
 
-import           Prelude              hiding (error)
-import           Control.Arrow        (second)
 import           Control.Applicative
+import           Control.Arrow        (second)
 import           Control.Monad.Catch
 import           Data.Aeson
 import           Data.Aeson.Types
@@ -23,12 +22,12 @@ import           Data.Monoid
 import           Data.Text            (Text, pack)
 import           Data.Text.Encoding
 import           GHC.Generics
-import           URI.ByteString
-import           URI.ByteString.Aeson ()
 import           Lens.Micro
 import           Lens.Micro.Extras
 import           Network.HTTP.Conduit as C
 import qualified Network.HTTP.Types   as H
+import           URI.ByteString
+import           URI.ByteString.Aeson ()
 
 --------------------------------------------------
 -- * Data Types
@@ -69,9 +68,9 @@ instance ToJSON OAuth2Token where
 
 data OAuth2Error a =
   OAuth2Error
-    { error :: Either Text a
+    { error            :: Either Text a
     , errorDescription :: Maybe Text
-    , errorUri :: Maybe (URIRef Absolute) }
+    , errorUri         :: Maybe (URIRef Absolute) }
   deriving (Show, Eq, Generic)
 
 instance FromJSON err => FromJSON (OAuth2Error err) where
@@ -88,8 +87,14 @@ instance ToJSON err => ToJSON (OAuth2Error err) where
 
 parseOAuth2Error :: FromJSON err => BSL.ByteString -> OAuth2Error err
 parseOAuth2Error string =
-  either (\err -> OAuth2Error (Left "Decode error") (Just $ pack $ "Error: " <> err <> "\n Original Response:\n" <> show (decodeUtf8 $ BSL.toStrict string)) Nothing) id (eitherDecode string)
+  either (mkDecodeOAuth2Error string) id (eitherDecode string)
 
+mkDecodeOAuth2Error :: BSL.ByteString -> String -> OAuth2Error err
+mkDecodeOAuth2Error response err =
+  OAuth2Error
+    (Left "Decode error")
+    (Just $ pack $ "Error: " <> err <> "\n Original Response:\n" <> show (decodeUtf8 $ BSL.toStrict response))
+    Nothing
 
 --------------------------------------------------
 -- * Types Synonym
